@@ -1,5 +1,5 @@
 ;;; psgml.el --- SGML-editing mode with parsing support
-;; $Id: psgml.el,v 1.16 2002/08/12 21:43:11 scop Exp $
+;; $Id: psgml.el,v 1.17 2002/08/25 10:21:24 scop Exp $
 
 ;; Copyright (C) 1993-1999 Lennart Staflin
 ;; Copyright (C) 1992 Free Software Foundation, Inc.
@@ -395,7 +395,8 @@ The tags should be given as strings."
 This is intended to be overridden by submodes of sgml-mode.")
 
 ;;; XEmacs change
-(defvar sgml-data-directory (or (locate-data-directory "psgml")
+(defvar sgml-data-directory (or (locate-data-directory "psgml-dtds")
+				(locate-data-directory "psgml")
 				(locate-data-directory "sgml"))
   "*Directory for pre-supplied data files (DTD's and such).
 Set this before loading psgml.")
